@@ -12,8 +12,21 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from .llm import LLM
-from .models import TTSModels, TTSVoices, WhisperModels
+"""OpenAI plugin for LiveKit Agents
+
+Support for OpenAI Realtime API, LLM, TTS, and STT APIs.
+
+Also includes support for a large number of OpenAI-compatible APIs including Azure OpenAI, Cerebras,
+Fireworks, Perplexity, Telnyx, xAI, Ollama, and DeepSeek.
+
+See https://docs.livekit.io/agents/integrations/openai/ and
+https://docs.livekit.io/agents/integrations/llm/ for more information.
+"""
+
+from . import realtime
+from .embeddings import EmbeddingData, create_embeddings
+from .llm import LLM, LLMStream
+from .models import STTModels, TTSModels, TTSVoices
 from .stt import STT
 from .tts import TTS
 from .version import __version__
@@ -22,21 +35,33 @@ __all__ = [
     "STT",
     "TTS",
     "LLM",
-    "WhisperModels",
+    "LLMStream",
+    "STTModels",
     "TTSModels",
     "TTSVoices",
+    "create_embeddings",
+    "EmbeddingData",
+    "realtime",
     "__version__",
 ]
 
 from livekit.agents import Plugin
 
+from .log import logger
+
 
 class OpenAIPlugin(Plugin):
     def __init__(self) -> None:
-        super().__init__(__name__, __version__, __package__)
-
-    def download_files(self) -> None:
-        pass
+        super().__init__(__name__, __version__, __package__, logger)
 
 
 Plugin.register_plugin(OpenAIPlugin())
+
+# Cleanup docs of unexported modules
+_module = dir()
+NOT_IN_ALL = [m for m in _module if m not in __all__]
+
+__pdoc__ = {}
+
+for n in NOT_IN_ALL:
+    __pdoc__[n] = False
